@@ -8,7 +8,10 @@ Usage::
     from mypy_boto3_codebuild import (
         Client,
         CodeBuildClient,
+        DescribeCodeCoveragesPaginator,
         DescribeTestCasesPaginator,
+        ListBuildBatchesForProjectPaginator,
+        ListBuildBatchesPaginator,
         ListBuildsForProjectPaginator,
         ListBuildsPaginator,
         ListProjectsPaginator,
@@ -24,7 +27,10 @@ Usage::
     client: CodeBuildClient = boto3.client("codebuild")
     session_client: CodeBuildClient = session.client("codebuild")
 
+    describe_code_coverages_paginator: DescribeCodeCoveragesPaginator = client.get_paginator("describe_code_coverages")
     describe_test_cases_paginator: DescribeTestCasesPaginator = client.get_paginator("describe_test_cases")
+    list_build_batches_paginator: ListBuildBatchesPaginator = client.get_paginator("list_build_batches")
+    list_build_batches_for_project_paginator: ListBuildBatchesForProjectPaginator = client.get_paginator("list_build_batches_for_project")
     list_builds_paginator: ListBuildsPaginator = client.get_paginator("list_builds")
     list_builds_for_project_paginator: ListBuildsForProjectPaginator = client.get_paginator("list_builds_for_project")
     list_projects_paginator: ListProjectsPaginator = client.get_paginator("list_projects")
@@ -37,7 +43,10 @@ Usage::
 """
 from mypy_boto3_codebuild.client import CodeBuildClient
 from mypy_boto3_codebuild.paginator import (
+    DescribeCodeCoveragesPaginator,
     DescribeTestCasesPaginator,
+    ListBuildBatchesForProjectPaginator,
+    ListBuildBatchesPaginator,
     ListBuildsForProjectPaginator,
     ListBuildsPaginator,
     ListProjectsPaginator,
@@ -54,7 +63,10 @@ Client = CodeBuildClient
 __all__ = (
     "Client",
     "CodeBuildClient",
+    "DescribeCodeCoveragesPaginator",
     "DescribeTestCasesPaginator",
+    "ListBuildBatchesForProjectPaginator",
+    "ListBuildBatchesPaginator",
     "ListBuildsForProjectPaginator",
     "ListBuildsPaginator",
     "ListProjectsPaginator",
